@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Data::Rx::Failure;
 {
-  $Data::Rx::Failure::VERSION = '0.200002';
+  $Data::Rx::Failure::VERSION = '0.200003';
 }
 # ABSTRACT: structured failure report from an Rx checker
 
@@ -114,7 +114,7 @@ sub stringify {
   my $struct = $self->struct;
 
   my $str = sprintf "Failed %s: %s (error: %s at %s)",
-    $self->error_types,
+    $struct->[0]{type},
     $struct->[0]{message},
     $self->error_string,
     $self->data_string;
@@ -136,6 +136,7 @@ sub stringify {
 1;
 
 __END__
+
 =pod
 
 =head1 NAME
@@ -144,7 +145,7 @@ Data::Rx::Failure - structured failure report from an Rx checker
 
 =head1 VERSION
 
-version 0.200002
+version 0.200003
 
 =head1 AUTHOR
 
@@ -152,10 +153,9 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Ricardo SIGNES.
+This software is copyright (c) 2013 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
